@@ -38,9 +38,10 @@ store_produce_aws_path <- function(store, name, object, path_store) {
   tar_assert_nonempty(endpoint %|||% "endpoint")
   tar_assert_chr(endpoint %|||% "endpoint")
   tar_assert_scalar(endpoint %|||% "endpoint")
-  prefix <- store$resources$aws$prefix %|||%
+  root_prefix <- store$resources$aws$prefix %|||%
     store$resources$prefix %|||%
-    tar_path_objects_dir_cloud()
+    path_store_default()
+  prefix <- path_objects_dir(path_store = root_prefix)
   tar_assert_nonempty(prefix)
   tar_assert_chr(prefix)
   tar_assert_scalar(prefix)
@@ -127,35 +128,22 @@ store_read_object.tar_aws <- function(store) {
   path <- store$file$path
   key <- store_aws_key(path)
   bucket <- store_aws_bucket(path)
-  scratch <- path_scratch(
-    path_store = path_scratch_dir_cloud(),
-    pattern = basename(store_aws_key(path))
-  )
+  scratch <- path_scratch_temp_network(pattern = basename(store_aws_key(path)))
   on.exit(unlink(scratch))
   dir_create(dirname(scratch))
-  seconds_interval <- store$resources$network$seconds_interval %|||% 1
-  seconds_timeout <- store$resources$network$seconds_timeout %|||% 30
-  max_tries <- store$resources$network$max_tries %|||% Inf
-  verbose <- store$resources$network$verbose %|||% TRUE
-  retry_until_true(
-    fun = ~{
-      aws_s3_download(
-        key = key,
-        bucket = bucket,
-        file = scratch,
-        region = store_aws_region(path),
-        endpoint = store_aws_endpoint(path),
-        version = store_aws_version(path),
-        args = store$resources$aws$args
-      )
-      TRUE
-    },
-    seconds_interval = seconds_interval,
-    seconds_timeout = seconds_timeout,
-    max_tries = max_tries,
-    catch_error = TRUE,
-    message = sprintf("Cannot download object %s from bucket %s", key, bucket),
-    verbose = verbose
+  aws <- store$resources$aws
+  aws_s3_download(
+    key = key,
+    bucket = bucket,
+    file = scratch,
+    region = store_aws_region(path),
+    endpoint = store_aws_endpoint(path),
+    version = store_aws_version(path),
+    args = aws$args,
+    max_tries = aws$max_tries,
+    seconds_timeout = aws$seconds_timeout,
+    close_connection = aws$close_connection,
+    s3_force_path_style = aws$s3_force_path_style
   )
   store_convert_object(store, store_read_path(store, scratch))
 }
@@ -163,13 +151,18 @@ store_read_object.tar_aws <- function(store) {
 #' @export
 store_exist_object.tar_aws <- function(store, name = NULL) {
   path <- store$file$path
+  aws <- store$resources$aws
   head <- aws_s3_exists(
     key = store_aws_key(path),
     bucket = store_aws_bucket(path),
     region = store_aws_region(path),
     endpoint = store_aws_endpoint(path),
     version = store_aws_version(path),
-    args = store$resources$aws$args
+    args = aws$args,
+    max_tries = aws$max_tries,
+    seconds_timeout = aws$seconds_timeout,
+    close_connection = aws$close_connection,
+    s3_force_path_style = aws$s3_force_path_style
   )
   !is.null(head)
 }
@@ -182,6 +175,7 @@ store_delete_object.tar_aws <- function(store, name = NULL) {
   region <- store_aws_region(path)
   endpoint <- store_aws_endpoint(path)
   version <- store_aws_version(path)
+  aws <- store$resources$aws
   message <- paste(
     "could not delete target %s from AWS bucket %s key %s.",
     "Either delete the object manually in the AWS web console",
@@ -196,7 +190,11 @@ store_delete_object.tar_aws <- function(store, name = NULL) {
       region = region,
       endpoint = endpoint,
       version = version,
-      args = store$resources$aws$args
+      args = aws$args,
+      max_tries = aws$max_tries,
+      seconds_timeout = aws$seconds_timeout,
+      close_connection = aws$close_connection,
+      s3_force_path_style = aws$s3_force_path_style
     ),
     error = function(condition) {
       tar_throw_validate(message, conditionMessage(condition))
@@ -213,33 +211,22 @@ store_upload_object.tar_aws <- function(store) {
 store_upload_object_aws <- function(store) {
   key <- store_aws_key(store$file$path)
   bucket <- store_aws_bucket(store$file$path)
-  seconds_interval <- store$resources$network$seconds_interval %|||% 1
-  seconds_timeout <- store$resources$network$seconds_timeout %|||% 30
-  max_tries <- store$resources$network$max_tries %|||% Inf
-  verbose <- store$resources$network$verbose %|||% TRUE
-  envir <- new.env(parent = emptyenv())
-  if_any(
+  aws <- store$resources$aws
+  head <- if_any(
     file_exists_stage(store$file),
-    retry_until_true(
-      ~{
-        envir$head <- aws_s3_upload(
-          file = store$file$stage,
-          key = key,
-          bucket = bucket,
-          region = store_aws_region(store$file$path),
-          endpoint = store_aws_endpoint(store$file$path),
-          metadata = list("targets-hash" = store$file$hash),
-          part_size = store$resources$aws$part_size %|||% (5 * (2 ^ 20)),
-          args = store$resources$aws$args
-        )
-        TRUE
-      },
-      seconds_interval = seconds_interval,
-      seconds_timeout = seconds_timeout,
-      max_tries = max_tries,
-      catch_error = TRUE,
-      message = sprintf("Cannot upload to object %s bucket %s", key, bucket),
-      verbose = verbose
+    aws_s3_upload(
+      file = store$file$stage,
+      key = key,
+      bucket = bucket,
+      region = store_aws_region(store$file$path),
+      endpoint = store_aws_endpoint(store$file$path),
+      metadata = list("targets-hash" = store$file$hash),
+      part_size = aws$part_size,
+      args = aws$args,
+      max_tries = aws$max_tries,
+      seconds_timeout = aws$seconds_timeout,
+      close_connection = aws$close_connection,
+      s3_force_path_style = aws$s3_force_path_style
     ),
     tar_throw_file(
       "Cannot upload non-existent AWS staging file ",
@@ -255,7 +242,7 @@ store_upload_object_aws <- function(store) {
     value = TRUE,
     invert = TRUE
   )
-  store$file$path <- c(path, paste0("version=", envir$head$VersionId))
+  store$file$path <- c(path, paste0("version=", head$VersionId))
   invisible()
 }
 
@@ -265,31 +252,24 @@ store_ensure_correct_hash.tar_aws <- function(store, storage, deployment) {
 
 #' @export
 store_has_correct_hash.tar_aws <- function(store) {
-  path <- store$file$path
-  bucket <- store_aws_bucket(path)
-  region <- store_aws_region(path)
-  endpoint <- store_aws_endpoint(path)
-  key <- store_aws_key(path)
-  version <- store_aws_version(path)
-  hash <- store_aws_hash(
-    key = key,
-    bucket = bucket,
-    region = region,
-    endpoint = endpoint,
-    version = version,
-    args = store$resources$aws$args
-  )
+  hash <- store_aws_hash(store)
   !is.null(hash) && identical(hash, store$file$hash)
 }
 
-store_aws_hash <- function(key, bucket, region, endpoint, version, args) {
+store_aws_hash <- function(store) {
+  path <- store$file$path
+  aws <- store$resources$aws
   head <- aws_s3_head(
-    key = key,
-    bucket = bucket,
-    region = region,
-    endpoint = endpoint,
-    version = version,
-    args = args
+    key = store_aws_key(path),
+    bucket = store_aws_bucket(path),
+    region = store_aws_region(path),
+    endpoint = store_aws_endpoint(path),
+    version = store_aws_version(path),
+    args = aws$args,
+    max_tries = aws$max_tries,
+    seconds_timeout = aws$seconds_timeout,
+    close_connection = aws$close_connection,
+    s3_force_path_style = aws$s3_force_path_style
   )
   head$Metadata[["targets-hash"]]
 }
