@@ -8,7 +8,8 @@ inspection_init <- function(
   allow = NULL,
   exclude = NULL,
   outdated = TRUE,
-  reporter = "silent"
+  reporter = "silent",
+  seconds_reporter = 0.5
 ) {
   inspection_new(
     pipeline = pipeline,
@@ -20,7 +21,8 @@ inspection_init <- function(
     allow = allow,
     exclude = exclude,
     outdated = outdated,
-    reporter = reporter
+    reporter = reporter,
+    seconds_reporter = seconds_reporter
   )
 }
 
@@ -35,6 +37,7 @@ inspection_new <- function(
   exclude = NULL,
   outdated = NULL,
   reporter = NULL,
+  seconds_reporter = NULL,
   vertices = NULL,
   edges = NULL,
   vertices_imports = NULL,
@@ -53,6 +56,7 @@ inspection_new <- function(
     exclude = exclude,
     outdated = outdated,
     reporter = reporter,
+    seconds_reporter = seconds_reporter,
     vertices = vertices,
     edges = edges,
     vertices_imports = vertices_imports,
@@ -71,6 +75,7 @@ inspection_class <- R6::R6Class(
   public = list(
     outdated = NULL,
     reporter = NULL,
+    seconds_reporter = NULL,
     initialize = function(
       pipeline = NULL,
       meta = NULL,
@@ -82,6 +87,7 @@ inspection_class <- R6::R6Class(
       exclude = NULL,
       outdated = NULL,
       reporter = NULL,
+      seconds_reporter = NULL,
       vertices = NULL,
       edges = NULL,
       vertices_imports = NULL,
@@ -107,6 +113,7 @@ inspection_class <- R6::R6Class(
       )
       self$outdated <- outdated
       self$reporter <- reporter
+      self$seconds_reporter <- seconds_reporter
     },
     hashes_to_vertices = function(hashes) {
       data_frame(
@@ -122,7 +129,8 @@ inspection_class <- R6::R6Class(
         meta = self$meta,
         names = self$names,
         shortcut = self$shortcut,
-        reporter = self$reporter
+        reporter = self$reporter,
+        seconds_reporter = self$seconds_reporter
       )
       outdated$run()
       names_outdated <- counter_get_names(outdated$outdated)
