@@ -26,7 +26,7 @@ tar_built <- function(
   names = NULL,
   store = targets::tar_config_get("store")
 ) {
-  tar_assert_allow_meta("tar_built")
+  tar_assert_allow_meta("tar_built", store)
   progress <- progress_init(path_store = store)
   progress <- tibble::as_tibble(progress$database$read_condensed_data())
   names_quosure <- rlang::enquo(names)
