@@ -52,7 +52,7 @@ tar_older <- function(
   inclusive = FALSE,
   store = targets::tar_config_get("store")
 ) {
-  tar_assert_allow_meta("tar_older")
+  tar_assert_allow_meta("tar_older", store)
   tar_assert_scalar(time)
   tar_assert_inherits(time, "POSIXct")
   tar_assert_scalar(inclusive)
