@@ -2,7 +2,7 @@
 #' @export
 #' @family help
 #' @description Create an example Target Markdown report
-#'   to get started with {targets}.
+#'   to get started with `targets`.
 #' @return `NULL` (invisibly).
 #' @param path Character of length 1, output path of the
 #'   Target Markdown report relative to the current active
@@ -18,7 +18,6 @@
 use_targets_rmd <- function(path = "_targets.Rmd", open = interactive()) {
   # Covered in tests/interactive/test-use_targets_rmd.R.
   # nocov start
-  tar_assert_allow_meta("use_targets_rmd")
   tar_assert_package("usethis")
   source <- file.path(
     "..",
