@@ -15,6 +15,7 @@ client <- function() {
 
 tar_test("aws qs format data gets stored", {
   skip_if_no_aws()
+  skip_if_no_gcp()
   skip_if_not_installed("qs")
   s3 <- client()
   bucket_name <- random_bucket_name()
@@ -26,7 +27,8 @@ tar_test("aws qs format data gets stored", {
         aws = tar_resources_aws(
           bucket = !!bucket_name,
           region = !!region,
-          endpoint = !!endpoint
+          endpoint = !!endpoint,
+          prefix = "_targets"
         )
       )
     )
@@ -71,6 +73,7 @@ tar_test("aws qs format data gets stored", {
 
 tar_test("aws qs format invalidation", {
   skip_if_no_aws()
+  skip_if_no_gcp()
   skip_if_not_installed("qs")
   s3 <- client()
   bucket_name <- random_bucket_name()
@@ -82,7 +85,8 @@ tar_test("aws qs format invalidation", {
         aws = tar_resources_aws(
           bucket = !!bucket_name,
           region = !!region,
-          endpoint = !!endpoint
+          endpoint = !!endpoint,
+          prefix = "_targets"
         )
       )
     )
@@ -106,7 +110,8 @@ tar_test("aws qs format invalidation", {
         aws = tar_resources_aws(
           bucket = !!bucket_name,
           region = !!region,
-          endpoint = !!endpoint
+          endpoint = !!endpoint,
+          prefix = "_targets"
         )
       )
     )
