@@ -10,7 +10,7 @@ tar_test("delete cloud targets", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     write_file <- function(path) {
@@ -44,11 +44,11 @@ tar_test("delete cloud targets", {
   path_store <- path_store_default()
   key1 <- path_objects(path_store, "x")
   key2 <- path_objects(path_store, "aws_file")
-  expect_true(aws_s3_exists(key = key1, bucket = bucket_name))
-  expect_true(aws_s3_exists(key = key2, bucket = bucket_name))
+  expect_true(aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L))
+  expect_true(aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L))
   tar_delete(everything())
-  expect_false(aws_s3_exists(key = key1, bucket = bucket_name))
-  expect_false(aws_s3_exists(key = key2, bucket = bucket_name))
+  expect_false(aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L))
+  expect_false(aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L))
   expect_true(file.exists("file.txt"))
   expect_silent(tar_delete(everything()))
   expect_silent(tar_delete(everything()))
@@ -71,7 +71,7 @@ tar_test("same with versioning", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     write_file <- function(path) {
@@ -105,11 +105,11 @@ tar_test("same with versioning", {
   path_store <- path_store_default()
   key1 <- path_objects(path_store, "x")
   key2 <- path_objects(path_store, "aws_file")
-  expect_true(aws_s3_exists(key = key1, bucket = bucket_name))
-  expect_true(aws_s3_exists(key = key2, bucket = bucket_name))
+  expect_true(aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L))
+  expect_true(aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L))
   tar_delete(everything())
-  expect_false(aws_s3_exists(key = key1, bucket = bucket_name))
-  expect_false(aws_s3_exists(key = key2, bucket = bucket_name))
+  expect_false(aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L))
+  expect_false(aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L))
   expect_true(file.exists("file.txt"))
   expect_silent(tar_delete(everything()))
 })
@@ -124,7 +124,7 @@ tar_test("tar_destroy() cloud targets", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     write_file <- function(path) {
@@ -159,11 +159,19 @@ tar_test("tar_destroy() cloud targets", {
     path_store <- path_store_default()
     key1 <- path_objects(path_store, "x")
     key2 <- path_objects(path_store, "aws_file")
-    expect_true(aws_s3_exists(key = key1, bucket = bucket_name))
-    expect_true(aws_s3_exists(key = key2, bucket = bucket_name))
+    expect_true(
+      aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L)
+    )
+    expect_true(
+      aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L)
+    )
     tar_destroy(destroy = destroy)
-    expect_false(aws_s3_exists(key = key1, bucket = bucket_name))
-    expect_false(aws_s3_exists(key = key2, bucket = bucket_name))
+    expect_false(
+      aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L)
+    )
+    expect_false(
+      aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L)
+    )
     expect_true(file.exists("file.txt"))
   }
   expect_silent(tar_destroy(destroy = "cloud"))
@@ -179,7 +187,7 @@ tar_test("tar_prune(), tar_exist_objects(), and tar_objects() for aws", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     write_file <- function(path) {
@@ -213,8 +221,8 @@ tar_test("tar_prune(), tar_exist_objects(), and tar_objects() for aws", {
   path_store <- path_store_default()
   key1 <- path_objects(path_store, "x")
   key2 <- path_objects(path_store, "aws_file")
-  expect_true(aws_s3_exists(key = key1, bucket = bucket_name))
-  expect_true(aws_s3_exists(key = key2, bucket = bucket_name))
+  expect_true(aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L))
+  expect_true(aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L))
   expect_equal(
     tar_exist_objects(c("x", "local_file", "aws_file")),
     c(TRUE, FALSE, TRUE)
@@ -223,7 +231,7 @@ tar_test("tar_prune(), tar_exist_objects(), and tar_objects() for aws", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     write_file <- function(path) {
@@ -251,8 +259,8 @@ tar_test("tar_prune(), tar_exist_objects(), and tar_objects() for aws", {
   path_store <- path_store_default()
   key1 <- path_objects(path_store, "x")
   key2 <- path_objects(path_store, "aws_file")
-  expect_false(aws_s3_exists(key = key1, bucket = bucket_name))
-  expect_true(aws_s3_exists(key = key2, bucket = bucket_name))
+  expect_false(aws_s3_exists(key = key1, bucket = bucket_name, max_tries = 1L))
+  expect_true(aws_s3_exists(key = key2, bucket = bucket_name, max_tries = 1L))
   expect_equal(
     tar_exist_objects(c("x", "local_file", "aws_file")),
     c(FALSE, FALSE, TRUE)
