@@ -89,7 +89,7 @@ tar_test("store_aws_file_stage() with targets <= 0.4.2", {
   skip_on_os("windows")
   path <- c("bucket_name", "key_name")
   out <- store_aws_file_stage(path)
-  expect_equal(dirname(out), file.path(path_scratch_dir_cloud(), "scratch"))
+  expect_equal(dirname(out), file.path(path_scratch_dir_network()))
   expect_true(grepl("targets_aws_file_key_name", basename(out)))
 })
 
