@@ -400,7 +400,7 @@ tar_test("local database cloud methods", {
   database <- database_init(repository = "local")
   expect_null(database$download())
   expect_null(database$upload())
-  expect_null(database$head())
+  expect_false(database$head()$exists)
   expect_null(database$delete_cloud())
 })
 
@@ -485,3 +485,73 @@ tar_test("mock sync local file more recent", {
   )
   expect_equal(x$sync(verbose = TRUE), "upload")
 })
+
+tar_test("mock failed nice_upload()", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  expect_silent(tmp <- x$nice_upload(verbose = FALSE, strict = FALSE))
+  expect_null(tmp)
+  expect_message(
+    tmp <- x$nice_upload(verbose = TRUE, strict = FALSE),
+    class = "tar_condition_run"
+  )
+  expect_null(tmp)
+  expect_error(
+    tmp <- x$nice_upload(verbose = TRUE, strict = TRUE),
+    class = "tar_condition_run"
+  )
+  expect_null(tmp)
+  expect_error(
+    tmp <- x$nice_upload(verbose = FALSE, strict = TRUE),
+    class = "tar_condition_run"
+  )
+  expect_null(tmp)
+})
+
+tar_test("mock succeeded nice_upload()", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  file.create(x$path)
+  for (strict in c(TRUE, FALSE)) {
+    expect_silent(tmp <- x$nice_upload(verbose = FALSE, strict = strict))
+    expect_equal(tmp, "upload")
+    expect_message(
+      tmp <- x$nice_upload(verbose = TRUE, strict = strict),
+      class = "tar_condition_run"
+    )
+    expect_equal(tmp, "upload")
+  }
+})
+
+tar_test("mock failed nice_download()", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  expect_silent(tmp <- x$nice_download(verbose = FALSE, strict = FALSE))
+  expect_null(tmp)
+  expect_message(
+    tmp <- x$nice_download(verbose = TRUE, strict = FALSE),
+    class = "tar_condition_run"
+  )
+  expect_null(tmp)
+  expect_error(
+    tmp <- x$nice_download(verbose = TRUE, strict = TRUE),
+    class = "tar_condition_run"
+  )
+  expect_null(tmp)
+  expect_error(
+    tmp <- x$nice_download(verbose = FALSE, strict = TRUE),
+    class = "tar_condition_run"
+  )
+  expect_null(tmp)
+})
+
+tar_test("mock succeeded nice_download()", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  file.create("path_cloud")
+  for (strict in c(TRUE, FALSE)) {
+    expect_silent(tmp <- x$nice_download(verbose = FALSE, strict = strict))
+    expect_equal(tmp, "download")
+    expect_message(
+      tmp <- x$nice_download(verbose = TRUE, strict = strict),
+      class = "tar_condition_run"
+    )
+    expect_equal(tmp, "download")
+  }
+})
