@@ -1,3 +1,11 @@
+tar_test("progress database subkey", {
+  out <- progress_init()
+  expect_equal(
+    out$database$key,
+    file.path(path_store_default(), "meta", "progress")
+  )
+})
+
 tar_test("progress$queued", {
   expect_silent(counter_validate(progress_init()$queued))
 })
