@@ -1,4 +1,5 @@
 tar_test("tar_branches() with a nontrivial pattern", {
+  skip_cran()
   tar_script(
     list(
       tar_target(x, seq_len(2)),
@@ -25,6 +26,7 @@ tar_test("tar_branches() with a nontrivial pattern", {
 })
 
 tar_test("tar_branches() with a random pattern", {
+  skip_cran()
   tar_script(
     list(
       tar_target(w, letters),
@@ -46,7 +48,7 @@ tar_test("tar_branches() with a random pattern", {
 })
 
 tar_test("custom script and store args", {
-  skip_on_cran()
+  skip_cran()
   expect_equal(tar_config_get("script"), path_script_default())
   expect_equal(tar_config_get("store"), path_store_default())
   tar_script({
